@@ -37,19 +37,21 @@ def AbsPath(path):
     return abspath
 
 @D_General
-def GetLocalPath(path):
+def GetLocalPath(path, silent=False):
     inPath = path
     if path.lower().startswith('hdfs://'):
         LogException(f'hdfs pathes are not local: {path}')
     elif path.lower().startswith('file://'):
-        Log(f'Removeing file:// from {path}')
+        if not silent:
+            Log(f'Removeing file:// from {path}')
         path = path[7:]
     path = os.path.abspath(path)
-    Log(f'Local path of {inPath} is {path}')
+    if not silent:
+        Log(f'Local path of {inPath} is {path}')
     return path
 
-def FileExist(path):
-    path = GetLocalPath(path)
+def FileExist(path, silent=False):
+    path = GetLocalPath(path, silent)
     return os.path.exists(path)
 
 @D_General
